@@ -304,7 +304,7 @@
     (gnc-make-qofinstance-option section name key docstring defval (GncOptionUIType-INVOICE))))
 (define-public (gnc:make-taxtable-option section name key docstring default)
   (issue-deprecation-warning "gnc:make-taxtable-option is deprecated. Make and register the option in one command with gnc-register-taxtable-option.")
-  (gnc-make-qofinstance-option section name key docstring default (GncOptionUIType-TAX_TABLE)))
+  (gnc-make-qofinstance-option section name key docstring default (GncOptionUIType-TAX-TABLE)))
 (define-public (gnc:make-counter-option section name key docstring default)
   (issue-deprecation-warning "gnc:make-number-range-option is deprecated. Make and register the option in one command with gnc-register-number-range-option.")
   (gnc-make-range-value-option section name key docstring default 0.0 999999999.0 1.0))
@@ -314,7 +314,7 @@
   (gnc-make-string-option section name key docstring default (GncOptionUIType-STRING)))
 (define-public (gnc:make-date-format-option section name key docstring default)
   (issue-deprecation-warning "gnc:make-date-format-option is deprecated. Make and register the option in one command with gnc-register-date-format-option.")
-  (gnc-make-string-option section name key docstring default (GncOptionUIType-DATE_FORMAT)))
+  (gnc-make-string-option section name key docstring default (GncOptionUIType-DATE-FORMAT)))
 (define-public (gnc:make-currency-option section name key docstring default)
   (issue-deprecation-warning "gnc:make-currency-option is deprecated. Make and register the option in one command with gnc-register-currency-option.")
   (gnc-make-currency-option section name key docstring default))
