@@ -703,7 +703,6 @@ load( state *s, char *testfile)
   while (fgets(buf, BUFSIZE, f) && (buf[0] != '.')) {
     ub4   curr = 0;                               /* current offset into buf */
     ub4   value;                                              /* token value */
-    token_type token;                                          /* token type */
     ub4   i;
     test *t;
 
@@ -836,7 +835,7 @@ parse_w( state *s, sb1 *myarg)
   ub4        dimension_number;
   ub4        curr = 0;
   ub4        fe_len, value;
-  ub4        i, j, k;
+  ub4        i, j;
   size_t     len = strlen(myarg);
   token_type t = parse_token(myarg, len, &curr, &value);
 
@@ -1162,7 +1161,7 @@ next_builder( state *s, feature *tuple, ub1 n)
     return FALSE;
   else if (tuple[i].f < s->dim[tuple[i].d]-1) {
     ++tuple[i].f;                                       /* increment feature */
-    for (i; i<n-1; ++i) {            /* reset all less significant positions */
+    for (; i<n-1; ++i) {            /* reset all less significant positions */
       tuple[i+1].d = tuple[i].d+1;
       tuple[i+1].f = 0;
     }
@@ -1170,7 +1169,7 @@ next_builder( state *s, feature *tuple, ub1 n)
   else {
     ++tuple[i].d;      /* increment least significant non-maxed-out position */
     tuple[i].f = (ub2)0;                                /* reset its feature */
-    for (i; i<n-1; ++i) {            /* reset all less significant positions */
+    for (; i<n-1; ++i) {            /* reset all less significant positions */
       tuple[i+1].d = tuple[i].d+1;
       tuple[i+1].f = 0;
     }
@@ -1185,8 +1184,6 @@ build_tuples( state *s, ub2 d, ub2 f)
   feature  offset[MAX_N];                                      /* n-1-tuples */
   feature  tuple[MAX_N];                      /* n-tuples that include (d,f) */
   sb4      i, j, n;
-  ub8      count = 0;
-  test    *t;
   tu_iter  ctx;
 
   if (s->tc[d][f] > 0 || s->n[d][f] == s->n_final) {
@@ -1244,7 +1241,6 @@ build_tuples( state *s, ub2 d, ub2 f)
       printf("jenny: could not insert tuple\n");
       return;
     }
-    ++count;
 
     /* next tuple */
   make_next_tuple:
@@ -1282,7 +1278,6 @@ test  *t,                                                /* test being built */
 ub1   *mut)              /* mut[i] = 1 if I am allowed to adjust dimension i */
 {
   ub4      i;
-  without *w;                               /* one of the disobeyed withouts */
   ub4      count;                        /* number of withouts currently hit */
   ub2      ndim;                                         /* size of dimord[] */
   ub2      temp;
@@ -1552,7 +1547,6 @@ cover_tuples( state *s)
 
     /* find a good test */
     for (i=0; i<GROUP_SIZE; ++i) {
-      tu_iter  ctx;
       sb4      this_count;
 
       /* generate a test that covers the first tuple */
@@ -1651,101 +1645,6 @@ cover_tuples( state *s)
   my_free((char *)curr_test);
 }
 
-static void
-prepare_reduce( state *s)
-{
-  feature tuple[MAX_N];
-  ub1     n = s->n_final;
-  ub4     t, d;
-
-  for (t=0; t<s->ntests; ++t) {
-    for (d=0; d<s->ndim; ++d) {
-      s->onec[t][d] = 0;
-    }
-  }
-
-  /* Iterate through all the tuples */
-  start_builder( s, tuple, n);
-
-  for (;;) {
-    sb4 i;
-    ub2 thistest;
-
-    for (i=0; i<n; ++i) {
-      s->tuple_tester->f[tuple[i].d] = tuple[i].f;
-    }
-    if (count_withouts(s->tuple_tester, s->wc2) ||
-        count_withouts(s->tuple_tester, s->wc3))
-      goto make_next_tuple;
-
-    for (i=0; i<s->ntests; ++i) {
-      ub1 j;
-      for (j=0; j<n; ++j)
-        if (s->t[i]->f[tuple[j].d] != tuple[j].f)
-          break;
-      if (j == n)
-        break;                              /* this test contains this tuple */
-    }
-
-    /* no tests cover this tuple */
-    if (i==s->ntests) {
-      printf("error: some tuple not covered at all\n");
-    } else {
-      thistest = i;
-      for (++i; i<s->ntests; ++i) {
-        ub1 j;
-        for (j=0; j<n; ++j)
-          if (s->t[i]->f[tuple[j].d] != tuple[j].f)
-            break;
-        if (j == n)
-          break;                            /* this test contains this tuple */
-      }
-      if (i == s->ntests) {
-        ub1 j;
-        for (j=0; j<n; ++j) {
-          tu_iter ctx;
-          (void)start_tuple(&ctx, &s->one[thistest][tuple[j].d], n,
-                            &s->onec[thistest][tuple[j].d]);
-          (void)insert_tuple(s, &ctx, tuple);
-        }
-      }
-    }
-
-  make_next_tuple:
-    for (i=0; i<n; ++i) {
-      s->tuple_tester->f[tuple[i].d] = (ub2)~0;
-    }
-    if (!next_builder( s, tuple, n))
-      break;
-  }
-}
-
-/* find a test to try to eliminate */
-static int
-which_test( state *s)
-{
-  ub4 t;
-  ub4 mincount = ~0;
-  ub4 mint = 0;                  /* test with the fewest once-covered tuples */
-  for (t=0; t<s->ntests; ++t) {
-    ub4 i, j=0;
-    for (i=0; i<s->ndim; ++i) {
-      j += s->onec[t][i];
-    }
-    if (j <= mincount) {
-      mincount = j;
-      mint = t;
-    }
-  }
-  return mint;
-}
-
-static void
-reduce_tests( state *s)
-{
-  prepare_reduce( s);
-}
-
 /* Confirm that every tuple is covered by either a testcase or a without */
 static int
 confirm( state *s)
@@ -1796,7 +1695,7 @@ confirm( state *s)
       break;                                                         /* done */
     else if (offset[i].f < s->dim[offset[i].d]-1) {
       ++offset[i].f;                                    /* increment feature */
-      for (i; i<n-1; ++i) {          /* reset all less significant positions */
+      for (; i<n-1; ++i) {          /* reset all less significant positions */
         offset[i+1].d = offset[i].d+1;
         offset[i+1].f = 0;
       }
@@ -1804,7 +1703,7 @@ confirm( state *s)
     else {
       ++offset[i].d;   /* increment least significant non-maxed-out position */
       offset[i].f = (ub2)0;                             /* reset its feature */
-      for (i; i<n-1; ++i) {          /* reset all less significant positions */
+      for (; i<n-1; ++i) {          /* reset all less significant positions */
         offset[i+1].d = offset[i].d+1;
         offset[i+1].f = 0;
       }
@@ -1824,7 +1723,6 @@ driver( int argc, char *argv[])
 
   if (parse(argc, argv, &s)) {               /* read the user's instructions */
     cover_tuples(&s);     /* generate testcases until all tuples are covered */
-    /* reduce_tests(&s); */         /* try to reduce the number of testcases */
     if (confirm(&s))       /* doublecheck that all tuples really are covered */
       report_all(&s);                                  /* report the results */
     else
