@@ -749,18 +749,12 @@ gnc_dialog_run (GtkDialog *dialog, const gchar *pref_name)
         return response;
 
     /* Add in the checkboxes to find out if the answer should be remembered. */
-#if 0
     if (GTK_IS_MESSAGE_DIALOG(dialog))
     {
         GtkMessageType type;
         g_object_get(dialog, "message-type", &type, (gchar*)NULL);
-        ask = (type == GTK_MESSAGE_QUESTION);
+        ask = (type == GTK_MESSAGE_QUESTION || type == GTK_MESSAGE_WARNING);
     }
-    else
-    {
-        ask = FALSE;
-    }
-#endif
     perm = gtk_check_button_new_with_mnemonic
            (ask
             ? _("Remember and don't _ask me again.")
@@ -776,6 +770,8 @@ gnc_dialog_run (GtkDialog *dialog, const gchar *pref_name)
     g_signal_connect(perm, "clicked", G_CALLBACK(gnc_perm_button_cb), temp);
 
     /* OK. Present the dialog. */
+    GtkWidget *button_cancel = gtk_dialog_get_widget_for_response(GTK_DIALOG(dialog), GTK_RESPONSE_CANCEL);
+    gtk_widget_grab_focus(button_cancel);
     response = gtk_dialog_run(dialog);
     if ((response == GTK_RESPONSE_NONE) || (response == GTK_RESPONSE_DELETE_EVENT))
     {
