@@ -25,6 +25,7 @@
 #include "gnc-option-gtk-ui.hpp"
 #include <config.h>  // for scanf format string
 #include <memory>
+#include <cstdint>
 #include <qof.h>
 #include <gnc-engine.h> // for GNC_MOD_GUI
 #include <gnc-commodity.h> // for GNC_COMMODITY
@@ -276,6 +277,7 @@ create_option_widget<GncOptionUIType::TEXT> (GncOption& option, GtkGrid *page_bo
     gtk_box_set_homogeneous (GTK_BOX (enclosing), FALSE);
     auto widget = gtk_text_view_new();
     gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(widget), GTK_WRAP_WORD);
+    gtk_widget_set_size_request(widget, 400, -1);
     gtk_text_view_set_editable(GTK_TEXT_VIEW(widget), TRUE);
     gtk_text_view_set_accepts_tab (GTK_TEXT_VIEW(widget), FALSE);
 
@@ -1104,6 +1106,10 @@ create_option_widget<GncOptionUIType::ACCOUNT_SEL> (GncOption& option,
     g_signal_connect(widget, "account_sel_changed",
                      G_CALLBACK(gnc_option_changed_widget_cb), &option);
     wrap_widget(option, widget, page_box, row);
+    // wrap_widget sets the parent so this comes after.
+    gtk_container_child_set(GTK_CONTAINER(gtk_widget_get_parent(widget)),
+                            widget, "fill", TRUE, "expand", TRUE,
+                            nullptr);
 }
 
 static void
