@@ -40,9 +40,9 @@
 
 #include "gnc-tree-view.h"
 #include "gnc-engine.h"
+#include "gnc-glib-utils.h"
 #include "gnc-gnome-utils.h"
 #include "gnc-gobject-utils.h"
-#include "gnc-cell-renderer-date.h"
 #include "gnc-cell-renderer-text-view.h"
 #include "gnc-state.h"
 #include "gnc-prefs.h"
@@ -77,8 +77,7 @@ enum
 static QofLogModule log_module = GNC_MOD_GUI;
 
 /**** Declarations ******************************************************/
-static void gnc_tree_view_class_init (GncTreeViewClass *klass);
-static void gnc_tree_view_init (GncTreeView *view, void *data);
+static void gnc_tree_view_constructed (GObject *object);
 static void gnc_tree_view_finalize (GObject *object);
 static void gnc_tree_view_destroy (GtkWidget *widget);
 static void gnc_tree_view_set_property (GObject         *object,
@@ -128,7 +127,7 @@ typedef struct GncTreeViewPrivate
     gulong             size_allocate_cb_id;
 } GncTreeViewPrivate;
 
-GNC_DEFINE_TYPE_WITH_CODE(GncTreeView, gnc_tree_view, GTK_TYPE_TREE_VIEW,
+G_DEFINE_TYPE_WITH_CODE(GncTreeView, gnc_tree_view, GTK_TYPE_TREE_VIEW,
                           G_ADD_PRIVATE(GncTreeView))
 
 #define GNC_TREE_VIEW_GET_PRIVATE(o)  \
@@ -142,8 +141,6 @@ GNC_DEFINE_TYPE_WITH_CODE(GncTreeView, gnc_tree_view, GTK_TYPE_TREE_VIEW,
 /** @name Gnc Tree View Object Implementation
  @{ */
 
-static GObjectClass *parent_class = NULL;
-
 /** Initialize the class for the new base gnucash tree view.  This
  *  will set up any function pointers that override functions in the
  *  parent class, and also installs the properties that are unique to
@@ -159,8 +156,6 @@ gnc_tree_view_class_init (GncTreeViewClass *klass)
     GObjectClass *gobject_class;
     GtkWidgetClass *gtkwidget_class;
 
-    parent_class = g_type_class_peek_parent (klass);
-
     gobject_class = G_OBJECT_CLASS(klass);
     gtkwidget_class = GTK_WIDGET_CLASS(klass);
 
@@ -183,6 +178,7 @@ gnc_tree_view_class_init (GncTreeViewClass *klass)
                                              G_PARAM_READWRITE));
 
     /* GObject signals */
+    gobject_class->constructed = gnc_tree_view_constructed;
     gobject_class->finalize = gnc_tree_view_finalize;
 
     /* GtkWidget signals */
@@ -236,17 +232,12 @@ gnc_tree_view_select_column_icon_cb (GtkWidget *widget, GdkEventButton *event, g
  *  @internal
  */
 static void
-gnc_tree_view_init (GncTreeView *view, void *data)
+gnc_tree_view_init (GncTreeView *view)
 {
     GncTreeViewPrivate *priv;
     GtkTreeViewColumn *column;
     GtkWidget *sep, *icon;
 
-    GncTreeViewClass *klass = (GncTreeViewClass*)data;
-
-    gnc_gobject_tracking_remember (G_OBJECT(view),
-                                   G_OBJECT_CLASS(klass));
-
     priv = GNC_TREE_VIEW_GET_PRIVATE(view);
     priv->column_menu = NULL;
     priv->show_column_menu = FALSE;
@@ -328,6 +319,20 @@ gnc_tree_view_init (GncTreeView *view, void *data)
     gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
 }
 
+/** The object has been fully constructed.
+ * This function adds the object to the tracking system.
+ *
+ *  @param obj The new object instance created by the object
+ *  system.
+ */
+ static void
+gnc_tree_view_constructed (GObject *obj)
+{
+    gnc_gobject_tracking_remember(obj);
+
+    G_OBJECT_CLASS (gnc_tree_view_parent_class)->constructed (obj);
+}
+
 /** Finalize the GncTreeView object.  This function is called from the
  *  G_Object level to complete the destruction of the object.  It
  *  should release any memory not previously released by the destroy
@@ -347,8 +352,7 @@ gnc_tree_view_finalize (GObject *object)
 
     gnc_gobject_tracking_forget (object);
 
-    if (G_OBJECT_CLASS(parent_class)->finalize)
-        G_OBJECT_CLASS(parent_class)->finalize (object);
+    G_OBJECT_CLASS(gnc_tree_view_parent_class)->finalize (object);
     LEAVE(" ");
 }
 
@@ -396,8 +400,7 @@ gnc_tree_view_destroy (GtkWidget *widget)
         priv->column_menu = NULL;
     }
 
-    if (GTK_WIDGET_CLASS(parent_class)->destroy)
-        GTK_WIDGET_CLASS(parent_class)->destroy (widget);
+    GTK_WIDGET_CLASS(gnc_tree_view_parent_class)->destroy (widget);
     LEAVE(" ");
 }
 
@@ -1287,6 +1290,21 @@ gnc_tree_view_create_menu_item (GtkTreeViewColumn *column,
     // LEAVE(" ");
 }
 
+static gint
+column_menu_sort (GtkTreeViewColumn *columna, GtkTreeViewColumn *columnb)
+{
+    const gchar *column_namea = g_object_get_data (G_OBJECT(columna), REAL_TITLE);
+    const gchar *column_nameb = g_object_get_data (G_OBJECT(columnb), REAL_TITLE);
+
+    if (!column_namea)
+        column_namea = gtk_tree_view_column_get_title (columna);
+
+    if (!column_nameb)
+        column_nameb = gtk_tree_view_column_get_title (columnb);
+
+    return safe_utf8_collate (column_namea, column_nameb);
+}
+
 /** This function is called to build the column selection menu.  It
  *  first destroys any old column selection menu, then checks to see
  *  if a new menu should be built.  If so, it calls the
@@ -1324,6 +1342,7 @@ gnc_tree_view_build_column_menu (GncTreeView *view)
 
         /* Now build a new menu */
         column_list = gtk_tree_view_get_columns (GTK_TREE_VIEW(view));
+        column_list = g_list_sort (column_list, (GCompareFunc)column_menu_sort);
         g_list_foreach (column_list, (GFunc)gnc_tree_view_create_menu_item, view);
         g_list_free (column_list);
     }
@@ -1362,9 +1381,10 @@ gnc_tree_view_update_column_menu_item (GtkCheckMenuItem *checkmenuitem,
     else
     {
         GBinding *binding = g_object_get_data (G_OBJECT(checkmenuitem), "column-binding");
-        GtkTreeViewColumn *column = GTK_TREE_VIEW_COLUMN(g_binding_get_target (binding));
+        GtkTreeViewColumn *column = GTK_TREE_VIEW_COLUMN(g_binding_dup_target (binding));
 
         visible = gtk_tree_view_column_get_visible (column);
+        g_object_unref(column);
     }
     gtk_check_menu_item_set_active (checkmenuitem, visible);
 }
@@ -1413,9 +1433,7 @@ void gnc_tree_view_expand_columns (GncTreeView *view,
                                    gchar *first_column_name,
                                    ...)
 {
-    GncTreeViewPrivate *priv;
     GtkTreeViewColumn *column;
-    gboolean hide_spacer;
     GList *columns, *tmp;
     gchar *name, *pref_name;
     va_list args;
@@ -1423,9 +1441,7 @@ void gnc_tree_view_expand_columns (GncTreeView *view,
     g_return_if_fail (GNC_IS_TREE_VIEW(view));
     ENTER(" ");
     va_start (args, first_column_name);
-    priv = GNC_TREE_VIEW_GET_PRIVATE(view);
     name = first_column_name;
-    hide_spacer = FALSE;
 
     /* First disable the expand property on all (non-infrastructure) columns. */
     columns = gtk_tree_view_get_columns (GTK_TREE_VIEW(view));
@@ -1445,7 +1461,6 @@ void gnc_tree_view_expand_columns (GncTreeView *view,
         if (column != NULL)
         {
             gtk_tree_view_column_set_expand (column, TRUE);
-            hide_spacer = TRUE;
         }
         name = va_arg (args, gchar*);
     }
@@ -1957,8 +1972,7 @@ gnc_tree_view_add_text_view_column (GncTreeView *view,
                                     column_sort_fn);
 }
 
-
-/** This function adds a new date column to a GncTreeView base view.
+/** This function adds a new pixbuf view column to a GncTreeView base view.
  *  It takes all the parameters necessary to hook a GtkTreeModel
  *  column to a GtkTreeViewColumn.  If the tree has a state section
  *  associated with it, this function also wires up the column so that
@@ -1967,41 +1981,33 @@ gnc_tree_view_add_text_view_column (GncTreeView *view,
  *  Parameters are defined in gnc-tree-view.h
  */
 GtkTreeViewColumn *
-gnc_tree_view_add_date_column (GncTreeView *view,
-                               const gchar *column_title,
-                               const gchar *pref_name,
-                               const gchar *icon_name,
-                               const gchar *sizing_text,
-                               gint model_data_column,
-                               gint model_visibility_column,
-                               GtkTreeIterCompareFunc column_sort_fn)
+gnc_tree_view_add_pix_column (GncTreeView *view,
+                              const gchar *column_title,
+                              const gchar *pref_name,
+                              const gchar *sizing_text,
+                              gint model_data_column,
+                              gint model_visibility_column,
+                              GtkTreeIterCompareFunc column_sort_fn)
 {
     GtkTreeViewColumn *column;
-    GtkCellRenderer *renderer;
     PangoLayout* layout;
     int default_width, title_width;
+    GtkCellRenderer *renderer;
 
     g_return_val_if_fail (GNC_IS_TREE_VIEW(view), NULL);
 
+    renderer = gtk_cell_renderer_pixbuf_new ();
+
     column = gtk_tree_view_column_new ();
     gtk_tree_view_column_set_title (column, column_title);
 
-    /* Set up an icon renderer if requested */
-    if (icon_name)
-    {
-        renderer = gtk_cell_renderer_pixbuf_new ();
-        g_object_set (renderer, "icon-name", icon_name, NULL);
-        gtk_tree_view_column_pack_start (column, renderer, FALSE);
-    }
-
     /* Set up a text renderer and attributes */
-    renderer = gnc_cell_renderer_date_new (TRUE);
     gtk_tree_view_column_pack_start (column, renderer, TRUE);
 
     /* Set renderer attributes controlled by the model */
     if (model_data_column != GNC_TREE_VIEW_COLUMN_DATA_NONE)
         gtk_tree_view_column_add_attribute (column, renderer,
-                                            "text", model_data_column);
+                                            "icon-name", model_data_column);
     if (model_visibility_column != GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS)
         gtk_tree_view_column_add_attribute (column, renderer,
                                             "visible", model_visibility_column);
@@ -2023,66 +2029,6 @@ gnc_tree_view_add_date_column (GncTreeView *view,
     return column;
 }
 
-
-GtkTreeViewColumn *
-gnc_tree_view_add_combo_column (GncTreeView *view,
-                                const gchar *column_title,
-                                const gchar *pref_name,
-                                const gchar *sizing_text,
-                                gint model_data_column,
-                                gint model_visibility_column,
-                                GtkTreeModel *combo_tree_model,
-                                gint combo_model_text_column,
-                                GtkTreeIterCompareFunc column_sort_fn)
-{
-    GtkTreeViewColumn *column;
-    GtkCellRenderer *renderer;
-    PangoLayout* layout;
-    int default_width, title_width;
-
-    g_return_val_if_fail (GNC_IS_TREE_VIEW(view), NULL);
-
-    column = gtk_tree_view_column_new ();
-    gtk_tree_view_column_set_title (column, gettext(column_title));
-
-    /* Set up a renderer and attributes */
-    renderer = gtk_cell_renderer_combo_new ();
-    gtk_tree_view_column_pack_start (column, renderer, TRUE);
-
-    /* Set renderer attributes controlled by the model */
-    if (model_data_column != GNC_TREE_VIEW_COLUMN_DATA_NONE)
-        gtk_tree_view_column_add_attribute (column, renderer,
-                                            "text", model_data_column);
-    if (model_visibility_column != GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS)
-        gtk_tree_view_column_add_attribute (column, renderer,
-                                            "visible", model_visibility_column);
-
-    /* Default size is the larger of the column title and the sizing text */
-    layout = gtk_widget_create_pango_layout (GTK_WIDGET(view), column_title);
-    pango_layout_get_pixel_size (layout, &title_width, NULL);
-    g_object_unref (layout);
-    layout = gtk_widget_create_pango_layout (GTK_WIDGET(view), sizing_text);
-    pango_layout_get_pixel_size (layout, &default_width, NULL);
-    g_object_unref (layout);
-    default_width = MAX(default_width, title_width);
-    if (default_width)
-        default_width += 10; /* padding on either side */
-
-    gnc_tree_view_column_properties (view, column, pref_name, model_data_column,
-                                     default_width, TRUE, column_sort_fn);
-
-    /* Stuff specific to combo */
-    if (combo_tree_model)
-    {
-        g_object_set (G_OBJECT(renderer), "model", combo_tree_model,
-                      "text-column", combo_model_text_column, NULL);
-    }
-    /* TODO: has-entry? */
-
-    gnc_tree_view_append_column (view, column);
-    return column;
-}
-
 GtkCellRenderer *
 gnc_tree_view_column_get_renderer (GtkTreeViewColumn *column)
 {
