@@ -93,7 +93,7 @@ static unsigned int periods[] =
 };
 
 /* This static indicates the debugging module that this .o belongs to.  */
-static QofLogModule log_module = GNC_MOD_GUI;
+__attribute__((unused)) static QofLogModule log_module = GNC_MOD_GUI;
 
 
 /** Prototypes **********************************************************/
@@ -194,9 +194,11 @@ gui_to_fi (FinCalcDialog *fcd)
     text = gtk_entry_get_text (GTK_ENTRY(entry));
     if (text && *text)
     {
-        gnc_numeric out;
-        gboolean result = string_to_gnc_numeric (text, &out);
-        npp = gnc_numeric_convert (out, 1, GNC_HOW_RND_TRUNC);
+        gnc_numeric out = gnc_numeric_from_string (text);
+        if (!gnc_numeric_check (out))
+            npp = gnc_numeric_convert (out, 1, GNC_HOW_RND_TRUNC);
+        else
+            npp = gnc_numeric_zero ();
     }
     else
         npp = gnc_numeric_zero ();
@@ -497,7 +499,7 @@ void fincalc_response_cb (GtkDialog *dialog,
     switch (response)
     {
     case GTK_RESPONSE_HELP:
-        gnc_gnome_help (GTK_WINDOW(dialog), HF_HELP, HL_FIN_CALC);
+        gnc_gnome_help (GTK_WINDOW(dialog), DF_MANUAL, DL_FIN_CALC);
         return;
 
     case GTK_RESPONSE_OK:
