@@ -240,7 +240,7 @@ static GncToolBarShortNames toolbar_labels[] =
     /* Translators: This string is meant to be a short alternative for "Save Report Configuration As…"
        to be used as toolbar button label. */
     { "ReportSaveAsAction",   N_("Save Config As…") },
-    { "FilePrintPDFAction",   N_("Make Pdf") },
+    { "FilePrintPDFAction",   N_("Export as PDF") },
     { nullptr, nullptr },
 };
 
@@ -1604,12 +1604,16 @@ gnc_get_export_filename (SCM choice, GtkWindow *parent)
     filepath = gnc_file_dialog (parent, title, nullptr, default_dir,
                                 GNC_FILE_DIALOG_EXPORT);
 
-    if (filepath != nullptr) // test for cancel pressed
+    /* Try to test for extension on file name, add if missing */
+    if (filepath && strchr (filepath, '.') == nullptr)
     {
-        /* Try to test for extension on file name, add if missing */
-        if (g_strrstr(filepath, ".") == nullptr)
-            filepath = g_strconcat(filepath, ".", g_ascii_strdown(type, strlen(type)), nullptr);
+        char* extension = g_ascii_strdown (type, -1);
+        char* newpath = g_strdup_printf ("%s.%s", filepath, extension);
+        g_free (extension);
+        g_free (filepath);
+        filepath = newpath;
     }
+
     g_free (type);
     g_free (title);
     g_free (default_dir);
