@@ -34,46 +34,38 @@
 #include "gnc-prefs.h"
 
 
-static void gnc_plugin_register_class_init (GncPluginRegisterClass *klass);
-static void gnc_plugin_register_init (GncPluginRegister *plugin);
 static void gnc_plugin_register_finalize (GObject *object);
 
 static void gnc_plugin_register_add_to_window (GncPlugin *plugin, GncMainWindow *window, GQuark type);
 static void gnc_plugin_register_remove_from_window (GncPlugin *plugin, GncMainWindow *window, GQuark type);
 
 /* Command callbacks */
-static void gnc_plugin_register_cmd_general_ledger (GtkAction *action, GncMainWindowActionData *data);
+static void gnc_plugin_register_cmd_general_ledger (GSimpleAction *simple, GVariant *parameter, gpointer user_data);
 
 #define PLUGIN_ACTIONS_NAME "gnc-plugin-register-actions"
-#define PLUGIN_UI_FILENAME  "gnc-plugin-register-ui.xml"
+#define PLUGIN_UI_FILENAME  "gnc-plugin-register.ui"
 
-static GtkActionEntry gnc_plugin_actions [] =
+static GActionEntry gnc_plugin_actions [] =
 {
-    {
-#ifdef REGISTER2_ENABLED
-        "ToolsGeneralJournalAction", NULL, N_("Old St_yle General Journal"), NULL,
-        N_("Open an old style general journal window"),
-        G_CALLBACK (gnc_plugin_register_cmd_general_ledger)
-#else
-        "ToolsGeneralJournalAction", NULL, N_("_General Journal"), NULL,
-        N_("Open general journal window"),
-        G_CALLBACK (gnc_plugin_register_cmd_general_ledger)
-#endif
-    },
+    { "ToolsGeneralJournalAction", gnc_plugin_register_cmd_general_ledger, NULL, NULL, NULL },
 };
-static guint gnc_plugin_n_actions = G_N_ELEMENTS (gnc_plugin_actions);
+/** The number of actions provided by this plugin. */
+static guint gnc_plugin_n_actions = G_N_ELEMENTS(gnc_plugin_actions);
 
-typedef struct GncPluginRegisterPrivate
+/** The default menu items that need to be add to the menu */
+static const gchar *gnc_plugin_load_ui_items [] =
 {
-    gpointer dummy;
-} GncPluginRegisterPrivate;
+    "ToolsPlaceholder2",
+    NULL,
+};
 
-G_DEFINE_TYPE_WITH_PRIVATE(GncPluginRegister, gnc_plugin_register, GNC_TYPE_PLUGIN)
+struct _GncPluginRegister
+{
+    GncPlugin gnc_plugin;
+};
 
-#define GNC_PLUGIN_REGISTER_GET_PRIVATE(o)  \
-   ((GncPluginRegisterPrivate*)gnc_plugin_register_get_instance_private((GncPluginRegister*)o))
+G_DEFINE_TYPE(GncPluginRegister, gnc_plugin_register, GNC_TYPE_PLUGIN)
 
-static GObjectClass *parent_class = NULL;
 static QofLogModule log_module = GNC_MOD_GUI;
 
 /************************************************************
@@ -126,8 +118,6 @@ gnc_plugin_register_class_init (GncPluginRegisterClass *klass)
     GObjectClass *object_class = G_OBJECT_CLASS (klass);
     GncPluginClass *plugin_class = GNC_PLUGIN_CLASS (klass);
 
-    parent_class = g_type_class_peek_parent (klass);
-
     object_class->finalize = gnc_plugin_register_finalize;
 
     /* plugin info */
@@ -139,10 +129,11 @@ gnc_plugin_register_class_init (GncPluginRegisterClass *klass)
         gnc_plugin_register_remove_from_window;
 
     /* widget addition/removal */
-    plugin_class->actions_name = PLUGIN_ACTIONS_NAME;
-    plugin_class->actions      = gnc_plugin_actions;
-    plugin_class->n_actions    = gnc_plugin_n_actions;
-    plugin_class->ui_filename  = PLUGIN_UI_FILENAME;
+    plugin_class->actions_name    = PLUGIN_ACTIONS_NAME;
+    plugin_class->actions         = gnc_plugin_actions;
+    plugin_class->n_actions       = gnc_plugin_n_actions;
+    plugin_class->ui_filename     = PLUGIN_UI_FILENAME;
+    plugin_class->ui_updates      = gnc_plugin_load_ui_items;
 }
 
 static void
@@ -155,7 +146,7 @@ gnc_plugin_register_finalize (GObject *object)
 {
     g_return_if_fail (GNC_IS_PLUGIN_REGISTER (object));
 
-    G_OBJECT_CLASS (parent_class)->finalize (object);
+    G_OBJECT_CLASS (gnc_plugin_register_parent_class)->finalize (object);
 }
 
 /************************************************************
@@ -212,9 +203,11 @@ gnc_plugin_register_remove_from_window (GncPlugin *plugin,
  ************************************************************/
 
 static void
-gnc_plugin_register_cmd_general_ledger (GtkAction *action,
-                                        GncMainWindowActionData *data)
+gnc_plugin_register_cmd_general_ledger (GSimpleAction *simple,
+                                        GVariant *parameter,
+                                        gpointer user_data)
 {
+    GncMainWindowActionData *data = user_data;
     GncPluginPage *page;
 
     g_return_if_fail (data != NULL);
