@@ -772,7 +772,7 @@ by preventing negative stock balances.<br/>")
                    )
                  )
                )
-             (xaccAccountGetSplitList current)
+             (xaccAccountGetSplits current)
              )
 
             ;; Look for income and expense transactions that don't have a split in the
@@ -832,7 +832,7 @@ by preventing negative stock balances.<br/>")
                       )
                     )
                   )
-                  (xaccAccountGetSplitList parent-account)
+                  (xaccAccountGetSplits parent-account)
                 )
               )
             )
