@@ -24,7 +24,6 @@
 (use-modules (gnucash engine))
 (use-modules (gnucash utilities))
 (use-modules (gnucash core-utils))
-(use-modules (gnucash app-utils))
 (use-modules (gnucash report))
 (use-modules (srfi srfi-13))
 (use-modules (gnucash html))
@@ -113,21 +112,19 @@ td.highlight {
 ")
 
 (define (css-options)
-  (let ((options (gnc:new-options)))
+  (let ((options (gnc-new-optiondb)))
 
-    (gnc:register-option
-     options
-     (gnc:make-text-option
+    (gnc-register-text-option options
       (N_ "General") (N_ "CSS") "a"
       (N_ "CSS code. This field specifies the CSS code for styling reports.")
-      default-css))
+      default-css)
 
     options))
 
 (define (css-renderer options doc)
 
   (let* ((ssdoc (gnc:make-html-document))
-         (css (gnc:option-value (gnc:lookup-option options "General" "CSS")))
+         (css (gnc-optiondb-lookup-value options "General" "CSS"))
          (report-css (or (gnc:html-document-style-text doc) ""))
          (all-css (string-append css report-css))
          (headline (or (gnc:html-document-headline doc)
