@@ -24,12 +24,16 @@
 #include "config.h"
 #include <glib.h>
 // GoogleTest is written in C++, however, the function we test in C.
-extern "C" {
-#include "../gnc-ui-balances.h"
-}
+#include "../gnc-autoclear.h"
 #include <memory>
+#include <cstdint>
+#include <Account.h>
 #include <Split.h>
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wcpp"
 #include <gtest/gtest.h>
+#pragma GCC diagnostic pop
+
 
 static const int64_t DENOM = 100; //< Denominator is always 100 for simplicity.
 
@@ -101,12 +105,147 @@ TestCase ambiguousTestCase = {
         { -10, "Cannot uniquely clear splits. Found multiple possibilities." },
         { -20, "Cannot uniquely clear splits. Found multiple possibilities." },
 
-        // Forbid auto-clear to be too smart. We expect the user to manually deal
-        // with such situations.
-        { -30, "Cannot uniquely clear splits. Found multiple possibilities." },
+        // -30 can be cleared by returning all three -10 splits
+        { -30, nullptr },
     },
 };
 
+
+TestCase sequentialTestCase1 =
+{
+    .splits = {
+        { "Memo 01", 2, false },
+        { "Memo 02", 3, false },
+        { "Memo 03", 5, false },
+    },
+    .tests = {
+        { 1, "The selected amount cannot be cleared." },
+        { 4, "The selected amount cannot be cleared." },
+        { 5, "Cannot uniquely clear splits. Found multiple possibilities." },
+        { 6, "The selected amount cannot be cleared." },
+        { 9, "The selected amount cannot be cleared." },
+        { 11, "The selected amount cannot be cleared." },
+        { 12, "The selected amount cannot be cleared." },
+        { 2, nullptr },
+        { 7, nullptr },
+        { 10, nullptr },
+    },
+};
+
+TestCase sequentialTestCase2 =
+{
+    .splits = {
+        { "Memo 01", 2, false },
+        { "Memo 02", 3, false },
+        { "Memo 03", 5, false },
+    },
+    .tests = {
+        { 3, nullptr },
+        { 8, nullptr },
+        { 10, nullptr },
+    },
+};
+
+
+TestCase sequentialTestCase3 =
+{
+    .splits = {
+        { "Memo 01", 2, false },
+        { "Memo 02", 3, false },
+        { "Memo 03", 5, false },
+        { "Memo 04", 5, false },
+    },
+    .tests = {
+        { 5, "Cannot uniquely clear splits. Found multiple possibilities." },
+        { 7, "Cannot uniquely clear splits. Found multiple possibilities." },
+        { 10, "Cannot uniquely clear splits. Found multiple possibilities." },
+        { 2, nullptr },
+        { 12, nullptr },
+        { 15, nullptr },
+    },
+};
+
+TestCase sequentialTestCase4 =
+{
+    .splits = {
+        { "Memo 01", 2, false },
+        { "Memo 02", 3, false },
+        { "Memo 03", 5, false },
+        { "Memo 04", 5, false },
+    },
+    .tests = {
+        { 3, nullptr },
+        { 13, nullptr },
+        { 15, nullptr },
+    },
+};
+
+TestCase slowTestCase =
+{
+    .splits = {
+        { "Memo 01", 1, false },
+        { "Memo 02", 2, false },
+        { "Memo 03", 4, false },
+        { "Memo 03", 8, false },
+        { "Memo 03", 16, false },
+        { "Memo 03", 32, false },
+        { "Memo 03", 64, false },
+        { "Memo 03", 128, false },
+        { "Memo 03", 256, false },
+        { "Memo 03", 512, false },
+        { "Memo 03", 1024, false },
+        { "Memo 03", 2048, false },
+        { "Memo 03", 4096, false },
+        { "Memo 03", 8192, false },
+        { "Memo 03", 16384, false },
+        { "Memo 03", 32768, false },
+        { "Memo 03", 65536, false },
+        { "Memo 03", 131072, false },
+        { "Memo 03", 262144, false },
+        { "Memo 03", 524288, false },
+        { "Memo 03", 1048576, false },
+    },
+    .tests = {
+        { 6000000, "The selected amount cannot be cleared." },
+        { 5000000, "The selected amount cannot be cleared." },
+        { 4000000, "The selected amount cannot be cleared." },
+        { 3000000, "The selected amount cannot be cleared." },
+        { 2000000, nullptr },
+    },
+};
+
+TestCase mixedSignsTestCase =
+{
+    .splits = {
+
+        { "memo 01", 30000 },
+        { "memo 01", -20000 },
+        { "memo 01", 10000 },
+        { "memo 01", 500 },
+        { "memo 01", -400 },
+        { "memo 01", 300 }
+    },
+    .tests = {
+        { 30300, nullptr },
+    },
+};
+
+TestCase testwithzerosTestCase =
+{
+    .splits = {
+        { "memo 01", 10000 },
+        { "memo 01", 0 },
+        { "memo 01", 10000 },
+        { "memo 01", 5000 },
+    },
+    .tests = {
+        { 19999, "The selected amount cannot be cleared." },
+        { 20001, "The selected amount cannot be cleared." },
+        { 20000, nullptr },
+    },
+};
+
+
 class AutoClearTest : public ::testing::TestWithParam<TestCase *> {
 protected:
     std::shared_ptr<QofBook> m_book;
@@ -119,6 +258,7 @@ public:
         m_account(xaccMallocAccount(m_book.get())),
         m_testCase(*GetParam())
     {
+        std::cout << "\n\ncreating new account with splits";
         xaccAccountSetName(m_account, "Test Account");
         xaccAccountBeginEdit(m_account);
         for (auto &d : m_testCase.splits) {
@@ -127,19 +267,28 @@ public:
             xaccSplitSetAmount(split, gnc_numeric_create(d.amount, DENOM));
             xaccSplitSetReconcile(split, d.cleared ? CREC : NREC);
             xaccSplitSetAccount(split, m_account);
+            std::cout << ' ' << d.amount;
 
             gnc_account_insert_split(m_account, split);
         }
         xaccAccountCommitEdit(m_account);
+        std::cout << std::endl;
     }
 };
 
 TEST_P(AutoClearTest, DoesAutoClear) {
     for (auto &t : m_testCase.tests) {
         gnc_numeric amount_to_clear = gnc_numeric_create(t.amount, DENOM);
-        char *err;
+        GError *error = nullptr;
 
-        GList *splits_to_clear = gnc_account_get_autoclear_splits(m_account, amount_to_clear, &err);
+        GList *splits_to_clear = gnc_account_get_autoclear_splits
+            (m_account, amount_to_clear, INT64_MAX, &error, 0);
+
+        auto err = error ? error->message : nullptr;
+
+        std::cout << "testing clearing " << t.amount
+                  << " should be [" << std::string (err ? err : "ok") << ']'
+                  << std::endl;
 
         // Actually clear splits
         for (GList *node = splits_to_clear; node; node = node->next) {
@@ -147,12 +296,16 @@ TEST_P(AutoClearTest, DoesAutoClear) {
             xaccSplitSetReconcile(split, CREC);
         }
 
-        ASSERT_STREQ(err, t.expectedErr);
+        g_list_free (splits_to_clear);
+
+        EXPECT_STREQ(err, t.expectedErr);
         if (t.expectedErr == NULL) {
             gnc_numeric c = xaccAccountGetClearedBalance(m_account);
-            ASSERT_EQ(c.num, t.amount);
-            ASSERT_EQ(c.denom, DENOM);
+            EXPECT_EQ(c.num, t.amount);
+            EXPECT_EQ(c.denom, DENOM);
         }
+        if (error)
+            g_error_free (error);
     }
 }
 
@@ -169,6 +322,13 @@ INSTANTIATE_TEST_SUITE_P(
     AutoClearTest,
     ::testing::Values(
         &easyTestCase,
+        &sequentialTestCase1,
+        &sequentialTestCase2,
+        &sequentialTestCase3,
+        &sequentialTestCase4,
+        &slowTestCase,
+        &mixedSignsTestCase,
+        &testwithzerosTestCase,
         &ambiguousTestCase
     )
 );
