@@ -167,18 +167,6 @@ struct invoice_pdata
     QofBook* book;
 };
 
-static inline gboolean
-set_string (xmlNodePtr node, GncInvoice* invoice,
-            void (*func) (GncInvoice* invoice, const char* txt))
-{
-    char* txt = dom_tree_to_text (node);
-    g_return_val_if_fail (txt, FALSE);
-
-    func (invoice, txt);
-
-    g_free (txt);
-    return TRUE;
-}
 
 static inline gboolean
 set_time64 (xmlNodePtr node, GncInvoice* invoice,
@@ -194,12 +182,11 @@ static gboolean
 invoice_guid_handler (xmlNodePtr node, gpointer invoice_pdata)
 {
     struct invoice_pdata* pdata = static_cast<decltype (pdata)> (invoice_pdata);
-    GncGUID* guid;
     GncInvoice* invoice;
 
-    guid = dom_tree_to_guid (node);
+    auto guid = dom_tree_to_guid (node);
     g_return_val_if_fail (guid, FALSE);
-    invoice = gncInvoiceLookup (pdata->book, guid);
+    invoice = gncInvoiceLookup (pdata->book, &*guid);
     if (invoice)
     {
         gncInvoiceDestroy (pdata->invoice);
@@ -208,11 +195,9 @@ invoice_guid_handler (xmlNodePtr node, gpointer invoice_pdata)
     }
     else
     {
-        gncInvoiceSetGUID (pdata->invoice, guid);
+        gncInvoiceSetGUID (pdata->invoice, &*guid);
     }
 
-    guid_free (guid);
-
     return TRUE;
 }
 
@@ -221,7 +206,7 @@ invoice_id_handler (xmlNodePtr node, gpointer invoice_pdata)
 {
     struct invoice_pdata* pdata = static_cast<decltype (pdata)> (invoice_pdata);
 
-    return set_string (node, pdata->invoice, gncInvoiceSetID);
+    return apply_xmlnode_text (gncInvoiceSetID, pdata->invoice, node);
 }
 
 static gboolean
@@ -257,7 +242,7 @@ invoice_billing_id_handler (xmlNodePtr node, gpointer invoice_pdata)
 {
     struct invoice_pdata* pdata = static_cast<decltype (pdata)> (invoice_pdata);
 
-    return set_string (node, pdata->invoice, gncInvoiceSetBillingID);
+    return apply_xmlnode_text (gncInvoiceSetBillingID, pdata->invoice, node);
 }
 
 static gboolean
@@ -265,7 +250,7 @@ invoice_notes_handler (xmlNodePtr node, gpointer invoice_pdata)
 {
     struct invoice_pdata* pdata = static_cast<decltype (pdata)> (invoice_pdata);
 
-    return set_string (node, pdata->invoice, gncInvoiceSetNotes);
+    return apply_xmlnode_text (gncInvoiceSetNotes, pdata->invoice, node);
 }
 
 static gboolean
@@ -286,14 +271,12 @@ static gboolean
 invoice_terms_handler (xmlNodePtr node, gpointer invoice_pdata)
 {
     struct invoice_pdata* pdata = static_cast<decltype (pdata)> (invoice_pdata);
-    GncGUID* guid;
     GncBillTerm* term;
 
-    guid = dom_tree_to_guid (node);
+    auto guid = dom_tree_to_guid (node);
     g_return_val_if_fail (guid, FALSE);
-    term = gnc_billterm_xml_find_or_create (pdata->book, guid);
+    term = gnc_billterm_xml_find_or_create (pdata->book, &*guid);
     g_assert (term);
-    guid_free (guid);
     gncInvoiceSetTerms (pdata->invoice, term);
 
     return TRUE;
@@ -303,13 +286,11 @@ static gboolean
 invoice_posttxn_handler (xmlNodePtr node, gpointer invoice_pdata)
 {
     struct invoice_pdata* pdata = static_cast<decltype (pdata)> (invoice_pdata);
-    GncGUID* guid;
     Transaction* txn;
 
-    guid = dom_tree_to_guid (node);
+    auto guid = dom_tree_to_guid (node);
     g_return_val_if_fail (guid, FALSE);
-    txn = xaccTransLookup (guid, pdata->book);
-    guid_free (guid);
+    txn = xaccTransLookup (&*guid, pdata->book);
     g_return_val_if_fail (txn, FALSE);
 
     gncInvoiceSetPostedTxn (pdata->invoice, txn);
@@ -320,13 +301,11 @@ static gboolean
 invoice_postlot_handler (xmlNodePtr node, gpointer invoice_pdata)
 {
     struct invoice_pdata* pdata = static_cast<decltype (pdata)> (invoice_pdata);
-    GncGUID* guid;
     GNCLot* lot;
 
-    guid = dom_tree_to_guid (node);
+    auto guid = dom_tree_to_guid (node);
     g_return_val_if_fail (guid, FALSE);
-    lot = gnc_lot_lookup (guid, pdata->book);
-    guid_free (guid);
+    lot = gnc_lot_lookup (&*guid, pdata->book);
     g_return_val_if_fail (lot, FALSE);
 
     gncInvoiceSetPostedLot (pdata->invoice, lot);
@@ -337,13 +316,11 @@ static gboolean
 invoice_postacc_handler (xmlNodePtr node, gpointer invoice_pdata)
 {
     struct invoice_pdata* pdata = static_cast<decltype (pdata)> (invoice_pdata);
-    GncGUID* guid;
     Account* acc;
 
-    guid = dom_tree_to_guid (node);
+    auto guid = dom_tree_to_guid (node);
     g_return_val_if_fail (guid, FALSE);
-    acc = xaccAccountLookup (guid, pdata->book);
-    guid_free (guid);
+    acc = xaccAccountLookup (&*guid, pdata->book);
     g_return_val_if_fail (acc, FALSE);
 
     gncInvoiceSetPostedAcc (pdata->invoice, acc);
