@@ -210,11 +210,10 @@ sx_id_handler (xmlNodePtr node, gpointer sx_pdata)
 {
     struct sx_pdata* pdata = static_cast<decltype (pdata)> (sx_pdata);
     SchedXaction* sx = pdata->sx;
-    GncGUID*        tmp = dom_tree_to_guid (node);
+    auto tmp = dom_tree_to_guid (node);
 
     g_return_val_if_fail (tmp, FALSE);
-    xaccSchedXactionSetGUID (sx, tmp);
-    guid_free (tmp);
+    xaccSchedXactionSetGUID (sx, &*tmp);
 
     return TRUE;
 }
@@ -224,52 +223,40 @@ gboolean
 sx_name_handler (xmlNodePtr node, gpointer sx_pdata)
 {
     struct sx_pdata* pdata = static_cast<decltype (pdata)> (sx_pdata);
-    SchedXaction* sx = pdata->sx;
-    gchar* tmp = dom_tree_to_text (node);
-    DEBUG ("sx named [%s]", tmp);
-    g_return_val_if_fail (tmp, FALSE);
-    xaccSchedXactionSetName (sx, tmp);
-    g_free (tmp);
-    return TRUE;
+    return apply_xmlnode_text (xaccSchedXactionSetName, pdata->sx, node);
 }
 
 static gboolean
 sx_enabled_handler (xmlNodePtr node, gpointer sx_pdata)
 {
     struct sx_pdata* pdata = static_cast<decltype (pdata)> (sx_pdata);
-    SchedXaction* sx = pdata->sx;
-    gchar* tmp = dom_tree_to_text (node);
-
-    sx->enabled = (g_strcmp0 (tmp, "y") == 0 ? TRUE : FALSE);
-    g_free (tmp);
-
-    return TRUE;
+    auto set_enabled = [](SchedXaction* sx, const char* txt)
+    {
+        sx->enabled = !g_strcmp0 (txt, "y");
+    };
+    return apply_xmlnode_text (set_enabled, pdata->sx, node);
 }
 
 static gboolean
 sx_autoCreate_handler (xmlNodePtr node, gpointer sx_pdata)
 {
     struct sx_pdata* pdata = static_cast<decltype (pdata)> (sx_pdata);
-    SchedXaction* sx = pdata->sx;
-    gchar* tmp = dom_tree_to_text (node);
-
-    sx->autoCreateOption = (g_strcmp0 (tmp, "y") == 0 ? TRUE : FALSE);
-    g_free (tmp);
-
-    return TRUE;
+    auto set_autocreate = [](SchedXaction* sx, const char* txt)
+    {
+        sx->autoCreateOption = !g_strcmp0 (txt, "y");
+    };
+    return apply_xmlnode_text (set_autocreate, pdata->sx, node);
 }
 
 static gboolean
 sx_notify_handler (xmlNodePtr node, gpointer sx_pdata)
 {
     struct sx_pdata* pdata = static_cast<decltype (pdata)> (sx_pdata);
-    SchedXaction* sx = pdata->sx;
-    gchar* tmp = dom_tree_to_text (node);
-
-    sx->autoCreateNotify = (g_strcmp0 (tmp, "y") == 0 ? TRUE : FALSE);
-    g_free (tmp);
-
-    return TRUE;
+    auto set_notify = [](SchedXaction* sx, const char* txt)
+    {
+        sx->autoCreateNotify = !g_strcmp0 (txt, "y");
+    };
+    return apply_xmlnode_text (set_notify, pdata->sx, node);
 }
 
 static gboolean
@@ -584,7 +571,7 @@ sx_templ_acct_handler (xmlNodePtr node, gpointer sx_pdata)
 {
     struct sx_pdata* pdata = static_cast<decltype (pdata)> (sx_pdata);
     SchedXaction* sx = pdata->sx;
-    GncGUID* templ_acct_guid = dom_tree_to_guid (node);
+    auto templ_acct_guid = dom_tree_to_guid (node);
     Account* account;
 
     if (!templ_acct_guid)
@@ -592,9 +579,8 @@ sx_templ_acct_handler (xmlNodePtr node, gpointer sx_pdata)
         return FALSE;
     }
 
-    account = xaccAccountLookup (templ_acct_guid, pdata->book);
+    account = xaccAccountLookup (&*templ_acct_guid, pdata->book);
     sx_set_template_account (sx, account);
-    guid_free (templ_acct_guid);
 
     return TRUE;
 }
