@@ -68,7 +68,6 @@
 #include <boost/locale.hpp>
 #include <regex>
 #include <iostream>
-#include <numeric>
 
 /* Below cvt and bfs_locale should be used with boost::filesystem::path (bfs)
  * objects created alter in this source file. The rationale is as follows:
@@ -1307,27 +1306,20 @@ gnc_filepath_locate_doc_file (const gchar *name)
     return result;
 }
 
-GList *
-gnc_list_all_paths (void)
+std::vector<EnvPaths>
+gnc_list_all_paths ()
 {
     if (gnc_userdata_home.empty())
         gnc_filepath_init ();
 
-    std::vector<EnvPaths> paths
-        { { "GNC_USERDATA_DIR", gnc_userdata_home_str.c_str(), true},
-          { "GNC_USERCONFIG_DIR", gnc_userconfig_home_str.c_str(), true },
-          { "GNC_BIN", g_getenv ("GNC_BIN"), false },
-          { "GNC_LIB", g_getenv ("GNC_LIB"), false },
-          { "GNC_CONF", g_getenv ("GNC_CONF"), false },
-          { "GNC_DATA", g_getenv ("GNC_DATA"), false },
-        };
-    auto accum = [](const auto& a, const auto& b)
-    {
-        EnvPaths *ep = g_new0 (EnvPaths, 1);
-        *ep = b;
-        return g_list_prepend (a, ep);
+    return {
+        { "GNC_DATA_HOME", gnc_userdata_home_str.c_str(), true},
+        { "GNC_CONFIG_HOME", gnc_userconfig_home_str.c_str(), true },
+        { "GNC_BIN", g_getenv ("GNC_BIN"), false },
+        { "GNC_LIB", g_getenv ("GNC_LIB"), false },
+        { "GNC_CONF", g_getenv ("GNC_CONF"), false },
+        { "GNC_DATA", g_getenv ("GNC_DATA"), false },
     };
-    return std::accumulate (paths.rbegin(), paths.rend(), (GList*) nullptr, accum);
 }
 
 static const std::regex
@@ -1347,4 +1339,11 @@ gboolean gnc_filename_is_datafile (const char *filename)
         std::regex_match (filename, datafile_regex);
 }
 
+std::ofstream
+gnc_open_filestream(const char* path)
+{
+    bfs::path bfs_path(path, cvt);
+    bfs_path.imbue(bfs_locale);
+    return std::ofstream(bfs_path.c_str());
+}
 /* =============================== END OF FILE ========================== */
