@@ -21,7 +21,12 @@
  *                                                                  *
  *******************************************************************/
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wcpp"
 #include <gtest/gtest.h>
+#pragma GCC diagnostic pop
+
+#include <cstdint>
 #include "../gnc-int128.hpp"
 
 TEST(GncInt128_constructors, test_default_constructor)
